Index: trunk/src/org/openstreetmap/josm/actions/AbstractMergeAction.java
===================================================================
--- trunk/src/org/openstreetmap/josm/actions/AbstractMergeAction.java	(revision 14272)
+++ trunk/src/org/openstreetmap/josm/actions/AbstractMergeAction.java	(revision 14273)
@@ -99,5 +99,5 @@
      * @param buttonText text of button used to select target layer
      * @param buttonIcon icon name of button used to select target layer
-     * @return choosen target layer
+     * @return chosen target layer
      */
     @SuppressWarnings("unchecked")
Index: trunk/src/org/openstreetmap/josm/actions/CloseChangesetAction.java
===================================================================
--- trunk/src/org/openstreetmap/josm/actions/CloseChangesetAction.java	(revision 14272)
+++ trunk/src/org/openstreetmap/josm/actions/CloseChangesetAction.java	(revision 14273)
@@ -152,6 +152,6 @@
 
         /**
-         * Returns the last exception that occured.
-         * @return the last exception that occured, or {@code null}
+         * Returns the last exception that occurred.
+         * @return the last exception that occurred, or {@code null}
          */
         public Exception getLastException() {
Index: trunk/src/org/openstreetmap/josm/actions/JosmAction.java
===================================================================
--- trunk/src/org/openstreetmap/josm/actions/JosmAction.java	(revision 14272)
+++ trunk/src/org/openstreetmap/josm/actions/JosmAction.java	(revision 14273)
@@ -228,5 +228,5 @@
 
     /**
-     * Overwrite this if {@link #updateEnabledState()} should be called when the active / availabe layers change. Default is true.
+     * Overwrite this if {@link #updateEnabledState()} should be called when the active / available layers change. Default is true.
      * @return <code>true</code> if a {@link LayerChangeListener} and a {@link ActiveLayerChangeListener} should be registered.
      * @since 10353
Index: trunk/src/org/openstreetmap/josm/actions/mapmode/DrawAction.java
===================================================================
--- trunk/src/org/openstreetmap/josm/actions/mapmode/DrawAction.java	(revision 14272)
+++ trunk/src/org/openstreetmap/josm/actions/mapmode/DrawAction.java	(revision 14273)
@@ -737,5 +737,5 @@
 
             // If ALT is pressed, a new way should be created and that new way should get
-            // selected. This works everytime unless the ways the nodes get inserted into
+            // selected. This works every time unless the ways the nodes get inserted into
             // are already selected. This is the case when creating a self-overlapping way
             // but pressing ALT prevents this. Therefore we must de-select the way manually
Index: trunk/src/org/openstreetmap/josm/command/RotateCommand.java
===================================================================
--- trunk/src/org/openstreetmap/josm/command/RotateCommand.java	(revision 14272)
+++ trunk/src/org/openstreetmap/josm/command/RotateCommand.java	(revision 14273)
@@ -35,5 +35,5 @@
     /**
      * Creates a RotateCommand.
-     * Assign the initial object set, compute pivot point and inital rotation angle.
+     * Assign the initial object set, compute pivot point and initial rotation angle.
      * @param objects objects to fetch nodes from
      * @param currentEN cuurent eats/north
Index: trunk/src/org/openstreetmap/josm/data/Version.java
===================================================================
--- trunk/src/org/openstreetmap/josm/data/Version.java	(revision 14272)
+++ trunk/src/org/openstreetmap/josm/data/Version.java	(revision 14273)
@@ -155,7 +155,7 @@
 
     /**
-     * Replies true if this is a local build, i.e. an inofficial development build.
-     *
-     * @return true if this is a local build, i.e. an inofficial development build.
+     * Replies true if this is a local build, i.e. an unofficial development build.
+     *
+     * @return true if this is a local build, i.e. an unofficial development build.
      */
     public boolean isLocalBuild() {
Index: trunk/src/org/openstreetmap/josm/data/cache/JCSCachedTileLoaderJob.java
===================================================================
--- trunk/src/org/openstreetmap/josm/data/cache/JCSCachedTileLoaderJob.java	(revision 14272)
+++ trunk/src/org/openstreetmap/josm/data/cache/JCSCachedTileLoaderJob.java	(revision 14273)
@@ -384,5 +384,5 @@
                     return true;
                 } else {
-                    Logging.debug("JCS - failure during load - reponse is not loadable nor cached as empty");
+                    Logging.debug("JCS - failure during load - response is not loadable nor cached as empty");
                     return false;
                 }
Index: trunk/src/org/openstreetmap/josm/data/imagery/WMTSTileSource.java
===================================================================
--- trunk/src/org/openstreetmap/josm/data/imagery/WMTSTileSource.java	(revision 14272)
+++ trunk/src/org/openstreetmap/josm/data/imagery/WMTSTileSource.java	(revision 14273)
@@ -490,5 +490,5 @@
         supportedMimeTypes.add("image/png8");           // used by geoserver
         if (supportedMimeTypes.contains("image/jpeg")) {
-            supportedMimeTypes.add("image/jpg"); // sometimes mispelled by Arcgis
+            supportedMimeTypes.add("image/jpg"); // sometimes misspelled by Arcgis
         }
         Collection<String> unsupportedFormats = new ArrayList<>();
Index: trunk/src/org/openstreetmap/josm/data/osm/Storage.java
===================================================================
--- trunk/src/org/openstreetmap/josm/data/osm/Storage.java	(revision 14272)
+++ trunk/src/org/openstreetmap/josm/data/osm/Storage.java	(revision 14273)
@@ -15,5 +15,5 @@
 /**
  * A Set-like class that allows looking up equivalent preexising instance.
- * It is useful whereever one would use self-mapping construct like
+ * It is useful wherever one would use self-mapping construct like
  * <code>Map&lt;T,T&gt;.put(t,t)</code>, that is, for caches, uniqueness filters or similar.
  *
Index: trunk/src/org/openstreetmap/josm/data/osm/visitor/paint/ArrowPaintHelper.java
===================================================================
--- trunk/src/org/openstreetmap/josm/data/osm/visitor/paint/ArrowPaintHelper.java	(revision 14272)
+++ trunk/src/org/openstreetmap/josm/data/osm/visitor/paint/ArrowPaintHelper.java	(revision 14273)
@@ -31,5 +31,5 @@
      * @param path The path to append the arrow to.
      * @param point The point to paint the tip at
-     * @param fromDirection The direction the line is comming from.
+     * @param fromDirection The direction the line is coming from.
      */
     public void paintArrowAt(MapPath2D path, MapViewPoint point, MapViewPoint fromDirection) {
Index: trunk/src/org/openstreetmap/josm/data/osm/visitor/paint/StyledMapRenderer.java
===================================================================
--- trunk/src/org/openstreetmap/josm/data/osm/visitor/paint/StyledMapRenderer.java	(revision 14272)
+++ trunk/src/org/openstreetmap/josm/data/osm/visitor/paint/StyledMapRenderer.java	(revision 14273)
@@ -162,5 +162,5 @@
             // Invert the sign bit, so that negative numbers are lower
             value ^= 0x80000000L;
-            // Now do the shift. Do it before accounting for negative numbers (symetry)
+            // Now do the shift. Do it before accounting for negative numbers (symmetry)
             if (totalBits < 32) {
                 value >>= (32 - totalBits);
Index: trunk/src/org/openstreetmap/josm/data/projection/datum/NTV2GridShiftFile.java
===================================================================
--- trunk/src/org/openstreetmap/josm/data/projection/datum/NTV2GridShiftFile.java	(revision 14272)
+++ trunk/src/org/openstreetmap/josm/data/projection/datum/NTV2GridShiftFile.java	(revision 14273)
@@ -46,5 +46,5 @@
  * Loading an InputStream places all the required node information
  * (accuracy data is optional) into heap based Java arrays. This is the
- * highest perfomance option, and is useful for large volume transformations.
+ * highest performance option, and is useful for large volume transformations.
  * Non-file data sources (eg using an SQL Blob) are also supported through
  * InputStream. The RandonAccessFile option has a much smaller memory
Index: trunk/src/org/openstreetmap/josm/data/projection/proj/AbstractProj.java
===================================================================
--- trunk/src/org/openstreetmap/josm/data/projection/proj/AbstractProj.java	(revision 14272)
+++ trunk/src/org/openstreetmap/josm/data/projection/proj/AbstractProj.java	(revision 14273)
@@ -112,5 +112,5 @@
      * Calculates the meridian distance. This is the distance along the central
      * meridian from the equator to {@code phi}. Accurate to &lt; 1e-5 meters
-     * when used in conjuction with typical major axis values.
+     * when used in conjunction with typical major axis values.
      *
      * @param phi latitude to calculate meridian distance for.
@@ -133,5 +133,5 @@
      * Determines phi to TOL (1e-11) radians, about 1e-6 seconds.
      *
-     * @param arg meridian distance to calulate latitude for.
+     * @param arg meridian distance to calculate latitude for.
      * @return the latitude of the meridian distance.
      * @throws RuntimeException if the itteration does not converge.
Index: trunk/src/org/openstreetmap/josm/data/projection/proj/EquidistantCylindrical.java
===================================================================
--- trunk/src/org/openstreetmap/josm/data/projection/proj/EquidistantCylindrical.java	(revision 14272)
+++ trunk/src/org/openstreetmap/josm/data/projection/proj/EquidistantCylindrical.java	(revision 14273)
@@ -37,5 +37,5 @@
     @Override
     public String getName() {
-        return tr("Equidistant Cylindrical (Plate Caree)");
+        return tr("Equidistant Cylindrical (Plate Carrée)");
     }
 
Index: trunk/src/org/openstreetmap/josm/data/projection/proj/ObliqueMercator.java
===================================================================
--- trunk/src/org/openstreetmap/josm/data/projection/proj/ObliqueMercator.java	(revision 14272)
+++ trunk/src/org/openstreetmap/josm/data/projection/proj/ObliqueMercator.java	(revision 14273)
@@ -142,5 +142,5 @@
 
     /**
-     * The azimuth of the central line passing throught the centre of the projection, in radians.
+     * The azimuth of the central line passing through the centre of the projection, in radians.
      */
     protected double azimuth;
Index: trunk/src/org/openstreetmap/josm/data/projection/proj/TransverseMercator.java
===================================================================
--- trunk/src/org/openstreetmap/josm/data/projection/proj/TransverseMercator.java	(revision 14272)
+++ trunk/src/org/openstreetmap/josm/data/projection/proj/TransverseMercator.java	(revision 14273)
@@ -16,6 +16,6 @@
  * Instead of being tangent to the equator (or to an other standard latitude),
  * it is tangent to a central meridian. Deformation are more important as we
- * are going futher from the central meridian. The Transverse Mercator
- * projection is appropriate for region wich have a greater extent north-south
+ * are going further from the central meridian. The Transverse Mercator
+ * projection is appropriate for region which have a greater extent north-south
  * than east-west.
  * <p>
Index: trunk/src/org/openstreetmap/josm/data/validation/routines/DomainValidator.java
===================================================================
--- trunk/src/org/openstreetmap/josm/data/validation/routines/DomainValidator.java	(revision 14272)
+++ trunk/src/org/openstreetmap/josm/data/validation/routines/DomainValidator.java	(revision 14273)
@@ -1881,9 +1881,9 @@
      */
     public enum ArrayType {
-        /** Update (or get a copy of) the GENERIC_TLDS_PLUS table containing additonal generic TLDs */
+        /** Update (or get a copy of) the GENERIC_TLDS_PLUS table containing additional generic TLDs */
         GENERIC_PLUS,
         /** Update (or get a copy of) the GENERIC_TLDS_MINUS table containing deleted generic TLDs */
         GENERIC_MINUS,
-        /** Update (or get a copy of) the COUNTRY_CODE_TLDS_PLUS table containing additonal country code TLDs */
+        /** Update (or get a copy of) the COUNTRY_CODE_TLDS_PLUS table containing additional country code TLDs */
         COUNTRY_CODE_PLUS,
         /** Update (or get a copy of) the COUNTRY_CODE_TLDS_MINUS table containing deleted country code TLDs */
Index: trunk/src/org/openstreetmap/josm/data/validation/routines/package.html
===================================================================
--- trunk/src/org/openstreetmap/josm/data/validation/routines/package.html	(revision 14272)
+++ trunk/src/org/openstreetmap/josm/data/validation/routines/package.html	(revision 14273)
@@ -20,5 +20,5 @@
 </head>
 <body bgcolor="white">
-    <p>This package contains <i>independant</i> validation routines adapted from Apache Commons Validator 1.5.0.</p>
+    <p>This package contains <i>independent</i> validation routines adapted from Apache Commons Validator 1.5.0.</p>
 <h1>Table of Contents</h1>
 
Index: trunk/src/org/openstreetmap/josm/data/validation/tests/Addresses.java
===================================================================
--- trunk/src/org/openstreetmap/josm/data/validation/tests/Addresses.java	(revision 14272)
+++ trunk/src/org/openstreetmap/josm/data/validation/tests/Addresses.java	(revision 14273)
@@ -263,5 +263,5 @@
         checkForDuplicate(r);
         if (r.hasTag("type", ASSOCIATED_STREET)) {
-            // Used to count occurences of each house number in order to find duplicates
+            // Used to count occurrences of each house number in order to find duplicates
             Map<String, List<OsmPrimitive>> map = new HashMap<>();
             // Used to detect different street names
Index: trunk/src/org/openstreetmap/josm/data/validation/tests/MapCSSTagChecker.java
===================================================================
--- trunk/src/org/openstreetmap/josm/data/validation/tests/MapCSSTagChecker.java	(revision 14272)
+++ trunk/src/org/openstreetmap/josm/data/validation/tests/MapCSSTagChecker.java	(revision 14273)
@@ -248,5 +248,5 @@
         /** Checks successfully parsed */
         public final List<TagCheck> parseChecks;
-        /** Errors that occured during parsing */
+        /** Errors that occurred during parsing */
         public final Collection<Throwable> parseErrors;
 
@@ -254,5 +254,5 @@
          * Constructs a new {@code ParseResult}.
          * @param parseChecks Checks successfully parsed
-         * @param parseErrors Errors that occured during parsing
+         * @param parseErrors Errors that occurred during parsing
          */
         public ParseResult(List<TagCheck> parseChecks, Collection<Throwable> parseErrors) {
Index: trunk/src/org/openstreetmap/josm/data/validation/tests/RelationChecker.java
===================================================================
--- trunk/src/org/openstreetmap/josm/data/validation/tests/RelationChecker.java	(revision 14272)
+++ trunk/src/org/openstreetmap/josm/data/validation/tests/RelationChecker.java	(revision 14273)
@@ -266,5 +266,5 @@
      * @param n relation to validate
      * @param allroles contains presets for specified relation
-     * @param map contains statistics of occurances of specified role types in relation
+     * @param map contains statistics of occurrences of specified role types in relation
      */
     private void checkRoles(Relation n, Map<Role, String> allroles, Map<String, RoleInfo> map) {
Index: trunk/src/org/openstreetmap/josm/gui/GettingStarted.java
===================================================================
--- trunk/src/org/openstreetmap/josm/gui/GettingStarted.java	(revision 14272)
+++ trunk/src/org/openstreetmap/josm/gui/GettingStarted.java	(revision 14273)
@@ -115,5 +115,5 @@
             // 1. Not yet written - but so isn't the interval variable, so it gets updated anyway
             // 2. Cannot be written (e.g. while developing). Obviously we don't want to update
-            // everytime because of something we can't read.
+            // every time because of something we can't read.
             return (Config.getPref().getInt("cache.motd.html.version", -999) == myVersion)
             && Config.getPref().get("cache.motd.html.java").equals(myJava)
Index: trunk/src/org/openstreetmap/josm/gui/MainApplication.java
===================================================================
--- trunk/src/org/openstreetmap/josm/gui/MainApplication.java	(revision 14272)
+++ trunk/src/org/openstreetmap/josm/gui/MainApplication.java	(revision 14273)
@@ -978,5 +978,5 @@
                 && !"true".equals(Utils.updateSystemProperty("java.net.preferIPv6Addresses", "true"))) {
             // never set this to false, only true!
-            Logging.info(tr("Try enabling IPv6 network, prefering IPv6 over IPv4 (only works on early startup)."));
+            Logging.info(tr("Try enabling IPv6 network, preferring IPv6 over IPv4 (only works on early startup)."));
         }
         Utils.updateSystemProperty("http.agent", Version.getInstance().getAgentString());
@@ -1193,7 +1193,7 @@
                                 Utils.updateSystemProperty("java.net.preferIPv6Addresses", "true");
                                 if (!wasv6) {
-                                    Logging.info(tr("Detected useable IPv6 network, prefering IPv6 over IPv4 after next restart."));
+                                    Logging.info(tr("Detected useable IPv6 network, preferring IPv6 over IPv4 after next restart."));
                                 } else {
-                                    Logging.info(tr("Detected useable IPv6 network, prefering IPv6 over IPv4."));
+                                    Logging.info(tr("Detected useable IPv6 network, preferring IPv6 over IPv4."));
                                 }
                                 hasv6 = true;
@@ -1207,5 +1207,5 @@
                 }
                 if (wasv6 && !hasv6) {
-                    Logging.info(tr("Detected no useable IPv6 network, prefering IPv4 over IPv6 after next restart."));
+                    Logging.info(tr("Detected no useable IPv6 network, preferring IPv4 over IPv6 after next restart."));
                     Config.getPref().putBoolean("validated.ipv6", hasv6); // be sure it is stored before the restart!
                     try {
Index: trunk/src/org/openstreetmap/josm/gui/MainFrame.java
===================================================================
--- trunk/src/org/openstreetmap/josm/gui/MainFrame.java	(revision 14272)
+++ trunk/src/org/openstreetmap/josm/gui/MainFrame.java	(revision 14273)
@@ -62,5 +62,5 @@
     /**
      * Create a new main window. The parameter will be removed in the future.
-     * @param geometry The inital geometry to use.
+     * @param geometry The initial geometry to use.
      * @since 12127
      */
Index: trunk/src/org/openstreetmap/josm/gui/bbox/BBoxChooser.java
===================================================================
--- trunk/src/org/openstreetmap/josm/gui/bbox/BBoxChooser.java	(revision 14272)
+++ trunk/src/org/openstreetmap/josm/gui/bbox/BBoxChooser.java	(revision 14273)
@@ -27,5 +27,5 @@
     /**
      * Replies the currently selected bounding box in this BBoxChooser.
-     * Replies null, if currently there isn't a bbox choosen in this
+     * Replies null, if currently there isn't a bbox chosen in this
      * BBoxChooser.
      *
Index: trunk/src/org/openstreetmap/josm/gui/bbox/SlippyMapBBoxChooser.java
===================================================================
--- trunk/src/org/openstreetmap/josm/gui/bbox/SlippyMapBBoxChooser.java	(revision 14272)
+++ trunk/src/org/openstreetmap/josm/gui/bbox/SlippyMapBBoxChooser.java	(revision 14273)
@@ -371,5 +371,5 @@
     /**
      * Sets the current bounding box in this bbox chooser without
-     * emiting a property change event.
+     * emitting a property change event.
      *
      * @param bbox the bounding box. null to reset the bounding box
Index: trunk/src/org/openstreetmap/josm/gui/bugreport/DebugTextDisplay.java
===================================================================
--- trunk/src/org/openstreetmap/josm/gui/bugreport/DebugTextDisplay.java	(revision 14272)
+++ trunk/src/org/openstreetmap/josm/gui/bugreport/DebugTextDisplay.java	(revision 14273)
@@ -35,5 +35,5 @@
 
     /**
-     * Creates a new text area with an inital text to display
+     * Creates a new text area with an initial text to display
      * @param textToDisplay The text to display.
      */
Index: trunk/src/org/openstreetmap/josm/gui/bugreport/JosmUpdatePanel.java
===================================================================
--- trunk/src/org/openstreetmap/josm/gui/bugreport/JosmUpdatePanel.java	(revision 14272)
+++ trunk/src/org/openstreetmap/josm/gui/bugreport/JosmUpdatePanel.java	(revision 14273)
@@ -76,5 +76,5 @@
      */
     private void displayError() {
-        testedVersionField.setText(tr("An error occured while checking if your JOSM instance is up to date."));
+        testedVersionField.setText(tr("An error occurred while checking if your JOSM instance is up to date."));
         showUpdateButton();
     }
Index: trunk/src/org/openstreetmap/josm/gui/datatransfer/data/LayerTransferData.java
===================================================================
--- trunk/src/org/openstreetmap/josm/gui/datatransfer/data/LayerTransferData.java	(revision 14272)
+++ trunk/src/org/openstreetmap/josm/gui/datatransfer/data/LayerTransferData.java	(revision 14273)
@@ -41,5 +41,5 @@
 
     /**
-     * Gets the layer to be transfered.
+     * Gets the layer to be transferred.
      * @return The layer
      */
Index: trunk/src/org/openstreetmap/josm/gui/datatransfer/data/PrimitiveTransferData.java
===================================================================
--- trunk/src/org/openstreetmap/josm/gui/datatransfer/data/PrimitiveTransferData.java	(revision 14272)
+++ trunk/src/org/openstreetmap/josm/gui/datatransfer/data/PrimitiveTransferData.java	(revision 14273)
@@ -22,5 +22,5 @@
 
 /**
- * A list of primitives that are transfered. The list allows you to implicitly add primitives.
+ * A list of primitives that are transferred. The list allows you to implicitly add primitives.
  * It distinguishes between primitives that were directly added and implicitly added ones.
  * @author Michael Zangl
Index: trunk/src/org/openstreetmap/josm/gui/dialogs/SelectionListDialog.java
===================================================================
--- trunk/src/org/openstreetmap/josm/gui/dialogs/SelectionListDialog.java	(revision 14272)
+++ trunk/src/org/openstreetmap/josm/gui/dialogs/SelectionListDialog.java	(revision 14273)
@@ -559,5 +559,5 @@
          * Replies the collection of OSM primitives currently selected in the view of this model
          *
-         * @return choosen elements in the view
+         * @return chosen elements in the view
          */
         public synchronized Collection<OsmPrimitive> getSelected() {
Index: trunk/src/org/openstreetmap/josm/gui/download/PlaceSelection.java
===================================================================
--- trunk/src/org/openstreetmap/josm/gui/download/PlaceSelection.java	(revision 14272)
+++ trunk/src/org/openstreetmap/josm/gui/download/PlaceSelection.java	(revision 14273)
@@ -269,5 +269,5 @@
                 if (!canceled) {
                     // Nominatim sometimes returns garbage, see #5934, #10643
-                    Logging.log(Logging.LEVEL_WARN, tr("Error occured with query ''{0}'': ''{1}''", urlString, e.getMessage()), e);
+                    Logging.log(Logging.LEVEL_WARN, tr("Error occurred with query ''{0}'': ''{1}''", urlString, e.getMessage()), e);
                     GuiHelper.runInEDTAndWait(() -> HelpAwareOptionPane.showOptionDialog(
                             MainApplication.getMainFrame(),
Index: trunk/src/org/openstreetmap/josm/gui/history/HistoryBrowserModel.java
===================================================================
--- trunk/src/org/openstreetmap/josm/gui/history/HistoryBrowserModel.java	(revision 14272)
+++ trunk/src/org/openstreetmap/josm/gui/history/HistoryBrowserModel.java	(revision 14273)
@@ -211,5 +211,5 @@
 
     /**
-     * Should be called everytime either reference of current changes to update the diff.
+     * Should be called every time either reference of current changes to update the diff.
      * TODO: Maybe rename to reflect this? eg. updateNodeListTableModels
      */
Index: trunk/src/org/openstreetmap/josm/gui/history/HistoryLoadTask.java
===================================================================
--- trunk/src/org/openstreetmap/josm/gui/history/HistoryLoadTask.java	(revision 14272)
+++ trunk/src/org/openstreetmap/josm/gui/history/HistoryLoadTask.java	(revision 14273)
@@ -235,6 +235,6 @@
 
     /**
-     * Returns the last exception that occured during loading, if any.
-     * @return the last exception that occured during loading, or {@code null}
+     * Returns the last exception that occurred during loading, if any.
+     * @return the last exception that occurred during loading, or {@code null}
      */
     public Exception getLastException() {
Index: trunk/src/org/openstreetmap/josm/gui/history/VersionInfoPanel.java
===================================================================
--- trunk/src/org/openstreetmap/josm/gui/history/VersionInfoPanel.java	(revision 14272)
+++ trunk/src/org/openstreetmap/josm/gui/history/VersionInfoPanel.java	(revision 14273)
@@ -230,5 +230,5 @@
      * Updates the content of this panel based on the changeset information given by {@code primitive}.
      * @param primitive the primitive to extract the changeset information from
-     * @param isLatest whether this relates to a not yet commited changeset
+     * @param isLatest whether this relates to a not yet committed changeset
      */
     public void update(final OsmPrimitive primitive, final boolean isLatest) {
@@ -239,5 +239,5 @@
      * Updates the content of this panel based on the changeset information given by {@code cs}.
      * @param cs the changeset information
-     * @param isLatest whether this relates to a not yet commited changeset
+     * @param isLatest whether this relates to a not yet committed changeset
      * @param timestamp the timestamp
      * @param version the version of the primitive
Index: trunk/src/org/openstreetmap/josm/gui/io/DownloadOpenChangesetsTask.java
===================================================================
--- trunk/src/org/openstreetmap/josm/gui/io/DownloadOpenChangesetsTask.java	(revision 14272)
+++ trunk/src/org/openstreetmap/josm/gui/io/DownloadOpenChangesetsTask.java	(revision 14273)
@@ -107,7 +107,7 @@
             // a username/password-pair.
             //
-            // Downgrade your knowlege about its identity if we've assumed that he was fully
+            // Downgrade your knowledge about its identity if we've assumed that he was fully
             // identified. Otherwise, if he is anonymous or partially identified, keep our level
-            // of knowlege.
+            // of knowledge.
             //
             if (im.isFullyIdentified()) {
Index: trunk/src/org/openstreetmap/josm/gui/io/SaveLayersDialog.java
===================================================================
--- trunk/src/org/openstreetmap/josm/gui/io/SaveLayersDialog.java	(revision 14272)
+++ trunk/src/org/openstreetmap/josm/gui/io/SaveLayersDialog.java	(revision 14273)
@@ -655,5 +655,5 @@
             if (numProblems == 0)
                 return;
-            Logging.warn(numProblems + " problems occured during upload/save");
+            Logging.warn(numProblems + " problems occurred during upload/save");
             String msg = trn(
                     "<html>An upload and/or save operation of one layer with modifications<br>"
Index: trunk/src/org/openstreetmap/josm/gui/layer/AbstractTileSourceLayer.java
===================================================================
--- trunk/src/org/openstreetmap/josm/gui/layer/AbstractTileSourceLayer.java	(revision 14272)
+++ trunk/src/org/openstreetmap/josm/gui/layer/AbstractTileSourceLayer.java	(revision 14273)
@@ -840,5 +840,5 @@
      * Zoom out from map.
      *
-     * @return    true, if zoom increasing was successfull, false othervise
+     * @return    true, if zoom increasing was successful, false othervise
      */
     public boolean decreaseZoomLevel() {
Index: trunk/src/org/openstreetmap/josm/gui/layer/gpx/DownloadAlongPanel.java
===================================================================
--- trunk/src/org/openstreetmap/josm/gui/layer/gpx/DownloadAlongPanel.java	(revision 14272)
+++ trunk/src/org/openstreetmap/josm/gui/layer/gpx/DownloadAlongPanel.java	(revision 14273)
@@ -110,6 +110,6 @@
 
     /**
-     * Gets the "download near" choosen value
-     * @return the "download near" choosen value (0: track only, 1: waypoints only, 2: both)
+     * Gets the "download near" chosen value
+     * @return the "download near" chosen value (0: track only, 1: waypoints only, 2: both)
      */
     public final int getNear() {
Index: trunk/src/org/openstreetmap/josm/gui/layer/imagery/TileCoordinateConverter.java
===================================================================
--- trunk/src/org/openstreetmap/josm/gui/layer/imagery/TileCoordinateConverter.java	(revision 14272)
+++ trunk/src/org/openstreetmap/josm/gui/layer/imagery/TileCoordinateConverter.java	(revision 14273)
@@ -113,5 +113,5 @@
      * Gets the position of the tile inside the map view.
      * @param tile The tile
-     * @return The positon as a rectangle in screen coordinates
+     * @return The position as a rectangle in screen coordinates
      */
     public Rectangle2D getRectangleForTile(Tile tile) {
Index: trunk/src/org/openstreetmap/josm/gui/mappaint/StyleSource.java
===================================================================
--- trunk/src/org/openstreetmap/josm/gui/mappaint/StyleSource.java	(revision 14272)
+++ trunk/src/org/openstreetmap/josm/gui/mappaint/StyleSource.java	(revision 14273)
@@ -141,5 +141,5 @@
 
     /**
-     * Log an error that occured with this style.
+     * Log an error that occurred with this style.
      * @param e error
      */
@@ -149,5 +149,5 @@
 
     /**
-     * Log a warning that occured with this style.
+     * Log a warning that occurred with this style.
      * @param w warnings
      */
@@ -157,5 +157,5 @@
 
     /**
-     * Replies the collection of errors that occured with this style.
+     * Replies the collection of errors that occurred with this style.
      * @return collection of errors
      */
@@ -165,5 +165,5 @@
 
     /**
-     * Replies the collection of warnings that occured with this style.
+     * Replies the collection of warnings that occurred with this style.
      * @return collection of warnings
      */
Index: trunk/src/org/openstreetmap/josm/gui/mappaint/mapcss/MapCSSException.java
===================================================================
--- trunk/src/org/openstreetmap/josm/gui/mappaint/mapcss/MapCSSException.java	(revision 14272)
+++ trunk/src/org/openstreetmap/josm/gui/mappaint/mapcss/MapCSSException.java	(revision 14273)
@@ -7,7 +7,7 @@
 public class MapCSSException extends RuntimeException {
 
-    /** line number at which the parse error occured */
+    /** line number at which the parse error occurred */
     protected Integer line;
-    /** column number at which the parse error occured */
+    /** column number at which the parse error occurred */
     protected Integer column;
 
@@ -30,6 +30,6 @@
 
     /**
-     * Sets the column number at which the parse error occured.
-     * @param column the column number at which the parse error occured
+     * Sets the column number at which the parse error occurred.
+     * @param column the column number at which the parse error occurred
      */
     public void setColumn(int column) {
@@ -38,6 +38,6 @@
 
     /**
-     * Sets the line number at which the parse error occured.
-     * @param line the line number at which the parse error occured
+     * Sets the line number at which the parse error occurred.
+     * @param line the line number at which the parse error occurred
      */
     public void setLine(int line) {
Index: trunk/src/org/openstreetmap/josm/gui/mappaint/styleelement/placement/OnLineStrategy.java
===================================================================
--- trunk/src/org/openstreetmap/josm/gui/mappaint/styleelement/placement/OnLineStrategy.java	(revision 14272)
+++ trunk/src/org/openstreetmap/josm/gui/mappaint/styleelement/placement/OnLineStrategy.java	(revision 14273)
@@ -134,5 +134,5 @@
         });
 
-        // find the segment with the best quality. If there are several with best quality, the one close to the center is prefered.
+        // find the segment with the best quality. If there are several with best quality, the one close to the center is preferred.
         return longHalfSegment.stream().max(
                 Comparator.comparingDouble(segment -> segment.quality - 1e-5 * Math.abs(segment.offset - length / 2)));
Index: trunk/src/org/openstreetmap/josm/gui/oauth/AuthorizationProcedureComboBox.java
===================================================================
--- trunk/src/org/openstreetmap/josm/gui/oauth/AuthorizationProcedureComboBox.java	(revision 14272)
+++ trunk/src/org/openstreetmap/josm/gui/oauth/AuthorizationProcedureComboBox.java	(revision 14273)
@@ -14,5 +14,5 @@
 
 /**
- * Combo box that lets the user choose one of the avaliable {@link AuthorizationProcedure}s.
+ * Combo box that lets the user choose one of the available {@link AuthorizationProcedure}s.
  */
 public class AuthorizationProcedureComboBox extends JosmComboBox<AuthorizationProcedure> {
Index: trunk/src/org/openstreetmap/josm/gui/preferences/PreferenceTabbedPane.java
===================================================================
--- trunk/src/org/openstreetmap/josm/gui/preferences/PreferenceTabbedPane.java	(revision 14272)
+++ trunk/src/org/openstreetmap/josm/gui/preferences/PreferenceTabbedPane.java	(revision 14273)
@@ -420,5 +420,5 @@
             if (task != null) {
                 // if we have to launch a plugin download task we do it asynchronously, followed
-                // by the remaining "save preferences" activites run on the Swing EDT.
+                // by the remaining "save preferences" activities run on the Swing EDT.
                 MainApplication.worker.submit(task);
                 MainApplication.worker.submit(() -> GuiHelper.runInEDT(continuation));
Index: trunk/src/org/openstreetmap/josm/gui/tagging/TagEditorModel.java
===================================================================
--- trunk/src/org/openstreetmap/josm/gui/tagging/TagEditorModel.java	(revision 14272)
+++ trunk/src/org/openstreetmap/josm/gui/tagging/TagEditorModel.java	(revision 14273)
@@ -712,5 +712,5 @@
 
     /**
-     * A listener that is called whenever the cells may be updated from outside the editor and the editor should thus be commited.
+     * A listener that is called whenever the cells may be updated from outside the editor and the editor should thus be committed.
      * @since 10604
      */
Index: trunk/src/org/openstreetmap/josm/gui/tagging/presets/TaggingPresetNameTemplateList.java
===================================================================
--- trunk/src/org/openstreetmap/josm/gui/tagging/presets/TaggingPresetNameTemplateList.java	(revision 14272)
+++ trunk/src/org/openstreetmap/josm/gui/tagging/presets/TaggingPresetNameTemplateList.java	(revision 14273)
@@ -48,7 +48,7 @@
 
     /**
-     * Finds and returns the first occurence of preset with template name matching the given primitive
+     * Finds and returns the first occurrence of preset with template name matching the given primitive
      * @param primitive The primitive to match
-     * @return the first occurence of preset with template name matching the primitive
+     * @return the first occurrence of preset with template name matching the primitive
      */
     public TaggingPreset findPresetTemplate(IPrimitive primitive) {
Index: trunk/src/org/openstreetmap/josm/gui/util/WindowGeometry.java
===================================================================
--- trunk/src/org/openstreetmap/josm/gui/util/WindowGeometry.java	(revision 14272)
+++ trunk/src/org/openstreetmap/josm/gui/util/WindowGeometry.java	(revision 14273)
@@ -366,5 +366,5 @@
 
     /**
-     * Determines if the bug affecting getMaximumWindowBounds() occured.
+     * Determines if the bug affecting getMaximumWindowBounds() occurred.
      *
      * @param maxbounds result of getMaximumWindowBounds()
Index: trunk/src/org/openstreetmap/josm/gui/widgets/JosmPasswordField.java
===================================================================
--- trunk/src/org/openstreetmap/josm/gui/widgets/JosmPasswordField.java	(revision 14272)
+++ trunk/src/org/openstreetmap/josm/gui/widgets/JosmPasswordField.java	(revision 14273)
@@ -130,5 +130,5 @@
                         pasteAction.actionPerformed(e);
                     } catch (NullPointerException npe) { // NOPMD
-                        Logging.log(Logging.LEVEL_ERROR, "NullPointerException occured because of JDK bug 6322854. "
+                        Logging.log(Logging.LEVEL_ERROR, "NullPointerException occurred because of JDK bug 6322854. "
                                 +"Copy/Paste operation has not been performed. Please complain to Oracle: "+
                                 "https://bugs.openjdk.java.net/browse/JDK-6322854", npe);
Index: trunk/src/org/openstreetmap/josm/gui/widgets/MultiSplitLayout.java
===================================================================
--- trunk/src/org/openstreetmap/josm/gui/widgets/MultiSplitLayout.java	(revision 14272)
+++ trunk/src/org/openstreetmap/josm/gui/widgets/MultiSplitLayout.java	(revision 14273)
@@ -592,5 +592,5 @@
      *
      * If the Dividers are "floating" then set the bounds of each
-     * node to accomodate the preferred size of all of the
+     * node to accommodate the preferred size of all of the
      * Leaf's java.awt.Components.  Otherwise, just set the bounds
      * of each Leaf/Split node so that it's to the left of (for
Index: trunk/src/org/openstreetmap/josm/io/DefaultProxySelector.java
===================================================================
--- trunk/src/org/openstreetmap/josm/io/DefaultProxySelector.java	(revision 14272)
+++ trunk/src/org/openstreetmap/josm/io/DefaultProxySelector.java	(revision 14273)
@@ -205,6 +205,6 @@
 
     /**
-     * Determines if proxy errors have occured.
-     * @return {@code true} if errors have occured, {@code false} otherwise.
+     * Determines if proxy errors have occurred.
+     * @return {@code true} if errors have occurred, {@code false} otherwise.
      * @since 6523
      */
Index: trunk/src/org/openstreetmap/josm/io/NetworkManager.java
===================================================================
--- trunk/src/org/openstreetmap/josm/io/NetworkManager.java	(revision 14272)
+++ trunk/src/org/openstreetmap/josm/io/NetworkManager.java	(revision 14273)
@@ -59,6 +59,6 @@
 
     /**
-     * Returns the network errors that occured until now.
-     * @return the network errors that occured until now, indexed by URL
+     * Returns the network errors that occurred until now.
+     * @return the network errors that occurred until now, indexed by URL
      */
     public static Map<String, Throwable> getNetworkErrors() {
Index: trunk/src/org/openstreetmap/josm/io/OsmApiException.java
===================================================================
--- trunk/src/org/openstreetmap/josm/io/OsmApiException.java	(revision 14272)
+++ trunk/src/org/openstreetmap/josm/io/OsmApiException.java	(revision 14273)
@@ -24,5 +24,5 @@
      * @param errorHeader The error header, as transmitted in the {@code Error} field of the HTTP response header
      * @param errorBody The error body, as transmitted in the HTTP response body
-     * @param accessedUrl The complete URL accessed when this error occured
+     * @param accessedUrl The complete URL accessed when this error occurred
      * @param login the login used to connect to OSM API (can be null)
      * @param contentType the response content-type
@@ -44,5 +44,5 @@
      * @param errorHeader The error header, as transmitted in the {@code Error} field of the HTTP response header
      * @param errorBody The error body, as transmitted in the HTTP response body
-     * @param accessedUrl The complete URL accessed when this error occured
+     * @param accessedUrl The complete URL accessed when this error occurred
      * @param login the login used to connect to OSM API (can be null)
      * @since 12992
@@ -58,5 +58,5 @@
      * @param errorHeader The error header, as transmitted in the {@code Error} field of the HTTP response header
      * @param errorBody The error body, as transmitted in the HTTP response body
-     * @param accessedUrl The complete URL accessed when this error occured
+     * @param accessedUrl The complete URL accessed when this error occurred
      * @since 5584
      */
@@ -216,7 +216,7 @@
 
     /**
-     * Sets the complete URL accessed when this error occured.
+     * Sets the complete URL accessed when this error occurred.
      * This is distinct from the one set with {@link #setUrl}, which is generally only the base URL of the server.
-     * @param url the complete URL accessed when this error occured.
+     * @param url the complete URL accessed when this error occurred.
      */
     public void setAccessedUrl(String url) {
@@ -225,7 +225,7 @@
 
     /**
-     * Replies the complete URL accessed when this error occured.
+     * Replies the complete URL accessed when this error occurred.
      * This is distinct from the one returned by {@link #getUrl}, which is generally only the base URL of the server.
-     * @return the complete URL accessed when this error occured.
+     * @return the complete URL accessed when this error occurred.
      */
     public String getAccessedUrl() {
Index: trunk/src/org/openstreetmap/josm/io/OsmApiInitializationException.java
===================================================================
--- trunk/src/org/openstreetmap/josm/io/OsmApiInitializationException.java	(revision 14272)
+++ trunk/src/org/openstreetmap/josm/io/OsmApiInitializationException.java	(revision 14273)
@@ -3,5 +3,5 @@
 
 /**
- * Exception thrown when a communication error occured with the OSM server during API initialization.
+ * Exception thrown when a communication error occurred with the OSM server during API initialization.
  * @see OsmApi#initialize
  */
Index: trunk/src/org/openstreetmap/josm/io/remotecontrol/handler/AddWayHandler.java
===================================================================
--- trunk/src/org/openstreetmap/josm/io/remotecontrol/handler/AddWayHandler.java	(revision 14272)
+++ trunk/src/org/openstreetmap/josm/io/remotecontrol/handler/AddWayHandler.java	(revision 14273)
@@ -47,5 +47,5 @@
 
     /**
-     * The place to remeber already added nodes (they are reused if needed @since 5845
+     * The place to remember already added nodes (they are reused if needed @since 5845
      */
     private Map<LatLon, Node> addedNodes;
Index: trunk/src/org/openstreetmap/josm/plugins/PluginDownloadTask.java
===================================================================
--- trunk/src/org/openstreetmap/josm/plugins/PluginDownloadTask.java	(revision 14272)
+++ trunk/src/org/openstreetmap/josm/plugins/PluginDownloadTask.java	(revision 14273)
@@ -213,6 +213,6 @@
 
     /**
-     * Replies the last exception that occured during download, or {@code null}.
-     * @return the last exception that occured during download, or {@code null}
+     * Replies the last exception that occurred during download, or {@code null}.
+     * @return the last exception that occurred during download, or {@code null}
      * @since 9621
      */
Index: trunk/src/org/openstreetmap/josm/plugins/PluginHandler.java
===================================================================
--- trunk/src/org/openstreetmap/josm/plugins/PluginHandler.java	(revision 14272)
+++ trunk/src/org/openstreetmap/josm/plugins/PluginHandler.java	(revision 14273)
@@ -271,5 +271,5 @@
 
     /**
-     * All exceptions that occured during plugin loading
+     * All exceptions that occurred during plugin loading
      */
     static final Map<String, Throwable> pluginLoadingExceptions = new HashMap<>();
@@ -1419,5 +1419,5 @@
             Throwable cause = current.getCause();
             if (cause != null && seen.contains(cause)) {
-                break; // circular refernce
+                break; // circular reference
             }
             current = cause;
Index: trunk/src/org/openstreetmap/josm/tools/Geometry.java
===================================================================
--- trunk/src/org/openstreetmap/josm/tools/Geometry.java	(revision 14272)
+++ trunk/src/org/openstreetmap/josm/tools/Geometry.java	(revision 14273)
@@ -366,5 +366,5 @@
         //  https://en.wikipedia.org/wiki/Line%E2%80%93line_intersection
         // However, large numbers lead to rounding errors (see #10286).
-        // To avoid this, p1 is first substracted from each of the points:
+        // To avoid this, p1 is first subtracted from each of the points:
         //  p1' = 0
         //  p2' = p2 - p1
Index: trunk/src/org/openstreetmap/josm/tools/Logging.java
===================================================================
--- trunk/src/org/openstreetmap/josm/tools/Logging.java	(revision 14272)
+++ trunk/src/org/openstreetmap/josm/tools/Logging.java	(revision 14273)
@@ -461,5 +461,5 @@
 
     /**
-     * Provides direct access to the logger used. Use of methods like {@link #warn(String)} is prefered.
+     * Provides direct access to the logger used. Use of methods like {@link #warn(String)} is preferred.
      * @return The logger
      */
Index: trunk/src/org/openstreetmap/josm/tools/MemoryManager.java
===================================================================
--- trunk/src/org/openstreetmap/josm/tools/MemoryManager.java	(revision 14272)
+++ trunk/src/org/openstreetmap/josm/tools/MemoryManager.java	(revision 14273)
@@ -116,5 +116,5 @@
          * Gets the content of this memory area.
          * <p>
-         * This method should be the prefered access to the memory since it will do error checking when {@link #free()} was called.
+         * This method should be the preferred access to the memory since it will do error checking when {@link #free()} was called.
          * @return The memory area content.
          */
Index: trunk/src/org/openstreetmap/josm/tools/PlatformHook.java
===================================================================
--- trunk/src/org/openstreetmap/josm/tools/PlatformHook.java	(revision 14272)
+++ trunk/src/org/openstreetmap/josm/tools/PlatformHook.java	(revision 14273)
@@ -60,5 +60,5 @@
 
     /**
-      * The preStartupHook will be called extremly early. It is
+      * The preStartupHook will be called extremely early. It is
       * guaranteed to be called before the GUI setup has started.
       *
Index: trunk/src/org/openstreetmap/josm/tools/PlatformHookWindows.java
===================================================================
--- trunk/src/org/openstreetmap/josm/tools/PlatformHookWindows.java	(revision 14272)
+++ trunk/src/org/openstreetmap/josm/tools/PlatformHookWindows.java	(revision 14273)
@@ -430,5 +430,5 @@
         } catch (ArrayIndexOutOfBoundsException e) {
             // catch error of JDK-8172244 as bug seems to not be fixed anytime soon
-            Logging.log(Logging.LEVEL_ERROR, "JDK-8172244 occured. Abort HTTPS setup", e);
+            Logging.log(Logging.LEVEL_ERROR, "JDK-8172244 occurred. Abort HTTPS setup", e);
             return false;
         }
Index: trunk/src/org/openstreetmap/josm/tools/XmlParsingException.java
===================================================================
--- trunk/src/org/openstreetmap/josm/tools/XmlParsingException.java	(revision 14272)
+++ trunk/src/org/openstreetmap/josm/tools/XmlParsingException.java	(revision 14273)
@@ -41,6 +41,6 @@
 
     /**
-     * Sets the location (line/column) where the exception occured.
-     * @param locator object giving the location (line/column) where the exception occured
+     * Sets the location (line/column) where the exception occurred.
+     * @param locator object giving the location (line/column) where the exception occurred
      * @return {@code this}
      */
@@ -65,6 +65,6 @@
 
     /**
-     * Returns the column number where the exception occured.
-     * @return the column number where the exception occured
+     * Returns the column number where the exception occurred.
+     * @return the column number where the exception occurred
      */
     public int getColumnNumber() {
@@ -73,6 +73,6 @@
 
     /**
-     * Returns the line number where the exception occured.
-     * @return the line number where the exception occured
+     * Returns the line number where the exception occurred.
+     * @return the line number where the exception occurred
      */
     public int getLineNumber() {
Index: trunk/src/org/openstreetmap/josm/tools/bugreport/BugReportSender.java
===================================================================
--- trunk/src/org/openstreetmap/josm/tools/bugreport/BugReportSender.java	(revision 14272)
+++ trunk/src/org/openstreetmap/josm/tools/bugreport/BugReportSender.java	(revision 14273)
@@ -161,5 +161,5 @@
 
     /**
-     * Returns the error message that could have occured during bug sending.
+     * Returns the error message that could have occurred during bug sending.
      * @return the error message, or {@code null} if successful
      */

Index: trunk/src/org/openstreetmap/josm/gui/MapViewState.java
===================================================================
--- trunk/src/org/openstreetmap/josm/gui/MapViewState.java	(revision 14272)
+++ trunk/src/org/openstreetmap/josm/gui/MapViewState.java	(revision 14273)
@@ -362,11 +362,11 @@
      * <p>
      * The view is moved so that the center is the same as the old center.
      * @param positon The new location to use.
      * @return The new state.
      * @since 10375
      */
-    public MapViewState usingLocation(JComponent positon) {
+    public MapViewState usingLocation(JComponent position) {
         EastNorth center = this.getCenter().getEastNorth();
-        return new MapViewState(positon, this).usingCenter(center);
+        return new MapViewState(position, this).usingCenter(center);
     }
 
@@ -541,5 +541,5 @@
         /**
          * Gets the direction in which this point is outside of the given view rectangle.
-         * @param rect The rectangle to check agains.
+         * @param rect The rectangle to check against.
          * @return The direction in which it is outside of the view, as OUTSIDE_... flags.
          * @since 10827
@@ -362,11 +362,11 @@
      * <p>
      * The view is moved so that the center is the same as the old center.
-     * @param positon The new location to use.
+     * @param position The new location to use.
      * @return The new state.
      * @since 10375